import { hashScrypt } from "../../utils/crypto.js";
export const createUserFunction = (auth) => {
    const createUser = async (provider, identifier, options) => {
        const providerId = `${provider}:${identifier}`;
        const attributes = options?.attributes || {};
        const userId = await auth.configs.generateCustomUserId();
        const hashedPassword = options?.password ? await hashScrypt(options.password) : null;
        const userData = await auth.configs.adapter.setUser(userId, {
            providerId,
            hashedPassword: hashedPassword,
            attributes
        });
        const user = auth.configs.transformUserData(userData);
        return user;
    };
    return createUser;
};
export const updateUserProviderIdFunction = (auth) => {
    const updateUserProviderId = async (userId, provider, identifier) => {
        const providerId = `${provider}:${identifier}`;
        const userData = await auth.configs.adapter.updateUser(userId, {
            providerId
        });
        const user = auth.configs.transformUserData(userData);
        return user;
    };
    return updateUserProviderId;
};
export const updateUserAttributesFunction = (auth) => {
    const updateUserAttributes = async (userId, attributes) => {
        const userData = await auth.configs.adapter.updateUser(userId, {
            attributes
        });
        const user = auth.configs.transformUserData(userData);
        return user;
    };
    return updateUserAttributes;
};
export const updateUserPasswordFunction = (auth) => {
    const updateUserPassword = async (userId, password) => {
        const hashedPassword = password ? await hashScrypt(password) : null;
        const [userData] = await Promise.all([
            auth.configs.adapter.updateUser(userId, {
                hashedPassword
            }),
            auth.configs.adapter.deleteSessionsByUserId(userId)
        ]);
        const user = auth.configs.transformUserData(userData);
        return user;
    };
    return updateUserPassword;
};
export const deleteUserFunction = (auth) => {
    const deleteUser = async (userId) => {
        await auth.configs.adapter.deleteSessionsByUserId(userId);
        await auth.configs.adapter.deleteUser(userId);
    };
    return deleteUser;
};
